@@ -3,9 +3,29 @@
 #	 st_as_sf(NextMethod()) # nocov
 #}
 
-group_split.sf <- function(.tbl, ..., keep = TRUE) {
+# This is currently only used in `bind_rows()` and `bind_cols()`
+# because sf overrides all default implementations
+dplyr_reconstruct.sf = function(data, template) {
+	sfc_name = attr(template, "sf_column")
+
+	# Return a bare data frame is the geometry column is no longer there
+	if (!sfc_name %in% names(data))
+		return(data)
+
+	prec = st_precision(template)
+	crs = st_crs(template)
+
+	st_as_sf(
+		data,
+		sf_column_name = sfc_name,
+		crs = crs,
+		precision = prec
+	)
+}
+
+group_split.sf <- function(.tbl, ..., .keep = TRUE) {
 	 class(.tbl) = setdiff(class(.tbl), "sf")
-     lapply(dplyr::group_split(.tbl, ..., keep = keep), st_as_sf)
+     lapply(dplyr::group_split(.tbl, ..., .keep = .keep), st_as_sf)
 }
 
 #' Tidyverse methods for sf objects (remove .sf suffix!)
@@ -103,19 +123,36 @@ transmute.sf <- function(.data, ..., .dots) {
 #' @details \code{select} keeps the geometry regardless whether it is selected or not; to deselect it, first pipe through \code{as.data.frame} to let dplyr's own \code{select} drop it.
 select.sf <- function(.data, ...) {
 
-	if (!requireNamespace("dplyr", quietly = TRUE))
-		stop("dplyr required: install that first") # nocov
+	if (!requireNamespace("tidyselect", quietly = TRUE))
+		stop("tidyselect required: install that first") # nocov
+	loc = tidyselect::eval_select(quote(c(...)), .data)
 
-	agr <- st_agr(.data)
-	class(.data) <- setdiff(class(.data), "sf")
-	sf_column <- attr(.data, "sf_column")
+	sf_column = attr(.data, "sf_column")
+	sf_column_loc = match(sf_column, names(.data))
 
-	if (!requireNamespace("rlang", quietly = TRUE))
-		stop("rlang required: install first?")
+	if (length(sf_column_loc) != 1 || is.na(sf_column_loc))
+		stop("internal error: can't find sf column") # nocov
 
-	ret <- dplyr::select(.data, ..., !! rlang::sym(sf_column))
-	vars <- setdiff(names(ret), sf_column)
-	st_set_agr(st_as_sf(ret, sf_column_name = sf_column), agr[vars])
+	agr = st_agr(.data)
+	vars = names(.data)[setdiff(loc, sf_column_loc)]
+	new_agr = agr[vars]
+
+	sf_column_loc_loc = match(sf_column_loc, loc)
+	if (is.na(sf_column_loc_loc)) {
+		# The sf column was subsetted out, select it back in
+		loc = c(sf_column_loc, loc)
+		names(loc)[[1]] = sf_column
+	} else {
+		# The sf column was not subsetted out but it might have been renamed
+		sf_column = names(loc[sf_column_loc_loc])
+	}
+
+	ret = .data
+	class(ret) = setdiff(class(ret), "sf")
+	ret = ret[loc]
+	names(ret) = names(loc)
+
+	st_set_agr(st_as_sf(ret, sf_column_name = sf_column), new_agr)
 }
 
 
@@ -135,7 +172,9 @@ rename.sf <- function(.data, ...) {
 #' @examples
 #' nc %>% slice(1:2)
 slice.sf <- function(.data, ..., .dots) {
-	st_as_sf(NextMethod(), sf_column_name = attr(.data, "sf_column"))
+	class(.data) <- setdiff(class(.data), "sf")
+	sf_column <- attr(.data, "sf_column")
+	st_as_sf(NextMethod(), sf_column_name = sf_column)
 }
 
 #' @name tidyverse
@@ -345,7 +384,7 @@ unite.sf <- function(data, col, ..., sep = "_", remove = TRUE) {
 }
 
 #' @name tidyverse
-#' @param .preserve see \link[tidyr]{unnest}
+#' @param .preserve see \link[tidyr:nest]{unnest}
 unnest.sf = function(data, ..., .preserve = NULL) {
 	# nocov start
 	sf_column_name = attr(data, "sf_column", exact = TRUE)
@@ -393,6 +432,13 @@ pillar_shaft.sfc <- function(x, ...) {
 }
 
 register_all_s3_methods = function() {
+	has_dplyr_1.0 =
+		requireNamespace("dplyr", quietly = TRUE) &&
+		utils::packageVersion("dplyr") >= "0.8.99.9000"
+
+	if (has_dplyr_1.0)
+		register_s3_method("dplyr", "dplyr_reconstruct", "sf")
+
 	register_s3_method("dplyr", "anti_join", "sf")
 	register_s3_method("dplyr", "arrange", "sf")
 	register_s3_method("dplyr", "distinct", "sf")
