@@ -20,7 +20,7 @@ test_that("st_crs works", {
 
   if (sf_extSoftVersion()[["GDAL"]] > "2.2.3") {
     expect_error(st_crs("+proj=ll"), "invalid crs")
-  	expect_error(st_crs("+proj=longlat +datum=NAD26"))
+  	# expect_error(st_crs("+proj=longlat +datum=NAD26"))
   }
   expect_silent(st_crs("+proj=longlat"))
   expect_silent(st_crs("+proj=longlat +datum=NAD27"))
